@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2021 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -128,9 +128,9 @@ class Monitos4xServer(GenericServer):
                 form_inputs['_password'] = self.password
 
                 # call login page to get temporary cookie
-                self.FetchURL('{0}/security/login'.format(self.monitor_url))
+                self.fetch_url('{0}/security/login'.format(self.monitor_url))
                 # submit login form to retrieve authentication cookie
-                self.FetchURL(
+                self.fetch_url(
                     '{0}/security/login_check'.format(self.monitor_url),
                     cgi_data=form_inputs,
                     multipart=True
@@ -164,15 +164,13 @@ class Monitos4xServer(GenericServer):
 
         # hosts
         try:
-            form_data = dict()
-
             page = 1
 
             # loop trough all api pages
             while True:
                 cgiurl_hosts_page = self.cgiurl_hosts + '&page=' + str(page)
 
-                result = self.FetchURL(
+                result = self.fetch_url(
                     cgiurl_hosts_page, giveback='raw', cgi_data=None)
 
                 # authentication errors get a status code 200 too
@@ -180,7 +178,7 @@ class Monitos4xServer(GenericServer):
                         result.result.startswith('<'):
                     # in case of auth error reset HTTP session and try again
                     self.reset_HTTP()
-                    result = self.FetchURL(
+                    result = self.fetch_url(
                         cgiurl_hosts_page, giveback='raw', cgi_data=None)
 
                     if result.status_code < 400 and \
@@ -220,7 +218,7 @@ class Monitos4xServer(GenericServer):
                     host_name = h['name']
 
                     if conf.debug_mode:
-                        self.Debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S') + ' host_name is: ' + host_name)
+                        self.debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S') + ' host_name is: ' + host_name)
 
                     # If a host does not exist, create its object
                     if host_name not in self.new_hosts:
@@ -280,7 +278,7 @@ class Monitos4xServer(GenericServer):
 
                         # extra duration needed for calculation
                         if h['status']['lastStateChange'] is None:
-                            self.Debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S') + 'Host has wrong lastStateChange - host_name is: ' + host_name)
+                            self.debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S') + 'Host has wrong lastStateChange - host_name is: ' + host_name)
                         else:
                             duration = datetime.datetime.now(
                             ) - datetime.datetime.fromtimestamp(int(h['status']['lastStateChange']))
@@ -295,21 +293,19 @@ class Monitos4xServer(GenericServer):
 
             # set checking flag back to False
             self.isChecking = False
-            result, error = self.Error(sys.exc_info())
+            result, error = self.error(sys.exc_info())
             return Result(result=result, error=error)
 
         # services
         try:
-            form_data = dict()
-
             page = 1
 
             # loop trough all api pages
             while True:
                 cgiurl_services_page = self.cgiurl_services + '&page=' + str(page)
 
-                result = self.FetchURL(cgiurl_services_page,
-                                       giveback='raw', cgi_data=None)
+                result = self.fetch_url(cgiurl_services_page,
+                                        giveback='raw', cgi_data=None)
 
                 # purify JSON result
                 jsonraw = copy.deepcopy(result.result.replace('\n', ''))
@@ -342,7 +338,7 @@ class Monitos4xServer(GenericServer):
                     service_name = s['configuration']['serviceDescription']
 
                     if conf.debug_mode:
-                        self.Debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S') + ' host_name is: ' + host_name + ' service_name is: ' + service_name)
+                        self.debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S') + ' host_name is: ' + host_name + ' service_name is: ' + service_name)
 
                     # If host not in problem list, create it
                     if host_name not in self.new_hosts:
@@ -411,7 +407,7 @@ class Monitos4xServer(GenericServer):
 
                         # extra duration needed for calculation
                         if s['status']['lastStateChange'] is None:
-                            self.Debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S')
+                            self.debug(server=self.get_name(), debug=time.strftime('%a %H:%M:%S')
                                                                      + 'Service has wrong lastStateChange - host_name is ' + host_name + ' service_name is: ' + service_name)
                         else:
                             duration = datetime.datetime.now(
@@ -427,7 +423,7 @@ class Monitos4xServer(GenericServer):
 
             # set checking flag back to False
             self.isChecking = False
-            result, error = self.Error(sys.exc_info())
+            result, error = self.error(sys.exc_info())
             return Result(result=result, error=error)
 
         del jsonraw, error, hosts
@@ -442,21 +438,19 @@ class Monitos4xServer(GenericServer):
             :param host: String - Host name
             :param service: String - Service name
         """
-        form_data = dict()
-
-        type = 'host'
+        type_ = 'host'
         if service == '':
             uuid = self.hosts[host].uuid
         else:
-            type = 'serviceinstance'
+            type_ = 'serviceinstance'
             uuid = self.hosts[host].services[service].uuid
 
         if self.use_autologin is True:
-            self.session.post('{0}/api/{1}/{2}/reschedule?authtoken={3}'.format(self.monitor_url, type ,uuid, self.autologin_key))
+            self.session.post('{0}/api/{1}/{2}/reschedule?authtoken={3}'.format(self.monitor_url, type_, uuid, self.autologin_key))
         else:
-            self.session.post('{0}/api/{1}/{2}/reschedule'.format(self.monitor_url, type ,uuid))
+            self.session.post('{0}/api/{1}/{2}/reschedule'.format(self.monitor_url, type_, uuid))
 
-    def _set_acknowledge(self, host, service, author, comment, sticky, notify, persistent, all_services=[]):
+    def _set_acknowledge(self, host, service, author, comment, sticky, notify, persistent, all_services=None):
         """
             Do a POST-Request to set an acknowledgement for a host, service or host with all services in monitos 4
 
@@ -467,13 +461,11 @@ class Monitos4xServer(GenericServer):
             :param sticky: Bool - Sticky Acknowledgement
             :param notify: Bool - Send Notifications
             :param persistent: Bool - Persistent comment
-            :param all_services: Array - List of all services (filled only if 'Acknowledge all services on host' is set)
+            :param all_services: Optional[Array] - List of all services (filled only if 'Acknowledge all services on host' is set)
         """
-        form_data = dict()
+        type_ = 'host'
 
-        type = 'host'
-
-        if len(all_services) > 0:  # Host & all Services
+        if all_services:  # Host & all Services
             uuid = self.hosts[host].uuid
             form_data = json.dumps(
                 {'comment': comment, 'notify': int(notify), 'persistent': int(persistent),
@@ -485,15 +477,15 @@ class Monitos4xServer(GenericServer):
                  'sticky': int(sticky), 'includeServices': 0})
         else:  # Service
             uuid = self.hosts[host].services[service].uuid
-            type = 'serviceinstance'
+            type_ = 'serviceinstance'
             form_data = json.dumps(
                 {'comment': comment, 'notify': int(notify),
                  'persistent': int(persistent), 'sticky': int(sticky)})
 
         if self.use_autologin is True:
-            self.session.post('{0}/api/{1}/{2}/acknowledge?authtoken={3}'.format(self.monitor_url, type ,uuid, self.autologin_key), data=form_data)
+            self.session.post('{0}/api/{1}/{2}/acknowledge?authtoken={3}'.format(self.monitor_url, type_ ,uuid, self.autologin_key), data=form_data)
         else:
-            self.session.post('{0}/api/{1}/{2}/acknowledge'.format(self.monitor_url, type ,uuid), data=form_data)
+            self.session.post('{0}/api/{1}/{2}/acknowledge'.format(self.monitor_url, type_,uuid), data=form_data)
 
     def _set_submit_check_result(self, host, service, state, comment, check_output, performance_data):
         """
@@ -508,9 +500,7 @@ class Monitos4xServer(GenericServer):
         """
         state = state.upper()
 
-        form_data = dict()
-
-        type = 'host'
+        type_ = 'host'
 
         if service == '':  # Host
             uuid = self.hosts[host].uuid
@@ -534,7 +524,7 @@ class Monitos4xServer(GenericServer):
                 log.info('Setting UNREACHABLE to CRITICAL')
                 state = 'CRITICAL'
 
-            type = 'serviceinstance'
+            type_ = 'serviceinstance'
             uuid = self.hosts[host].services[service].uuid
 
             state_number = self.STATES_MAPPING_REV['services'][state]
@@ -547,9 +537,9 @@ class Monitos4xServer(GenericServer):
                     {'exit_status': state_number, 'plugin_output': check_output, 'performance_data': performance_data})
 
         if self.use_autologin is True:
-            self.session.post('{0}/api/{1}/{2}/checkresult?authtoken={3}'.format(self.monitor_url, type ,uuid, self.autologin_key), data=form_data)
+            self.session.post('{0}/api/{1}/{2}/checkresult?authtoken={3}'.format(self.monitor_url, type_ ,uuid, self.autologin_key), data=form_data)
         else:
-            self.session.post('{0}/api/{1}/{2}/checkresult'.format(self.monitor_url, type ,uuid), data=form_data)
+            self.session.post('{0}/api/{1}/{2}/checkresult'.format(self.monitor_url, type_ ,uuid), data=form_data)
 
     def _set_downtime(self, host, service, author, comment, fixed, start_time, end_time, hours, minutes):
         """
@@ -565,13 +555,11 @@ class Monitos4xServer(GenericServer):
             :param hours: Integer - Flexible Downtime
             :param minutes: Integer - Flexible Downtime
         """
-        form_data = dict()
-
         if service == '':
-            type = 'sv_host'
+            type_ = 'sv_host'
             uuid = self.hosts[host].uuid
         else:
-            type = 'sv_service_status'
+            type_ = 'sv_service_status'
             uuid = self.hosts[host].services[service].uuid
 
         # Format start_time and end_time from user-friendly format to timestamp
@@ -589,13 +577,13 @@ class Monitos4xServer(GenericServer):
             form_data = json.dumps({'start': start_time, 'end': end_time, 'comment': comment,
                                     'is_recurring': 'FALSE', 'includeServices': 'TRUE',
                                     'includeChildren': 'FALSE', 'schedule_now': 'FALSE',
-                                    'id': uuid, 'type': type})
+                                    'id': uuid, 'type': type_})
 
         else:
             form_data = json.dumps({'start': start_time, 'end': end_time, 'comment': comment,
                                     'is_recurring': 'FALSE', 'includeServices': 'TRUE',
                                     'includeChildren': 'FALSE', 'schedule_now': 'FALSE',
-                                    'id': uuid, 'duration': duration, 'type': type})
+                                    'id': uuid, 'duration': duration, 'type': type_})
 
         if self.use_autologin is True:
             self.session.post('{0}/api/downtime?authtoken={1}'.format(self.monitor_url, self.autologin_key), data=form_data)
