@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2021 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
+from argparse import ArgumentParser
 import os
 import platform
 import sys
-import argparse
 import configparser
 import base64
 import zlib
@@ -45,29 +45,35 @@ if KEYRING:
 # instead of calling platform.system() every now and then just do it once here
 OS = platform.system()
 # needed when OS-specific decisions have to be made, mostly Linux/non-Linux
-OS_DARWIN = 'Darwin'
+OS_MACOS = 'Darwin'
 OS_WINDOWS = 'Windows'
-OS_NON_LINUX = (OS_DARWIN, OS_WINDOWS)
+OS_NON_LINUX = (OS_MACOS, OS_WINDOWS)
 
 # simple Wayland detection
 if 'WAYLAND_DISPLAY' in os.environ or\
     'XDG_SESSION_TYPE' in os.environ and os.environ['XDG_SESSION_TYPE'] == 'wayland':
+    # dirty workaround to activate X11 support in Wayland environment - just a test
+    if not os.environ.get('QT_QPA_PLATFORM'):
+        os.environ['QT_QPA_PLATFORM'] = 'xcb'
     DESKTOP_WAYLAND = True
 else:
     DESKTOP_WAYLAND = False
 
-# Cinnamon detection
-# CINNAMON_VERSION 4.2.4
-# DESKTOP_SESSION cinnamon
-# GDMSESSION cinnamon
-# XDG_CURRENT_DESKTOP X-Cinnamon
-# XDG_SESSION_DESKTOP cinnamon
-if 'CINNAMON_VERSION' in os.environ or\
-    'DESKTOP_SESSION' in os.environ and os.environ['DESKTOP_SESSION'] == 'cinnamon' or \
-    'XDG_SESSION_DESKTOP' in os.environ and os.environ['XDG_SESSION_DESKTOP'] == 'cinnamon':
-    DESKTOP_CINNAMON = True
+# detection of somehow quirky desktop enviroments which might need a fix
+QUIRKY_DESKTOPS =  ('cinnamon', 'gnome-flashback-metacity')
+if os.environ.get('CINNAMON_VERSION') or\
+    os.environ.get('DESKTOP_SESSION') in QUIRKY_DESKTOPS or \
+    os.environ.get('XDG_SESSION_DESKTOP') in QUIRKY_DESKTOPS:
+    DESKTOP_NEEDS_FIX = True
 else:
-    DESKTOP_CINNAMON = False
+    DESKTOP_NEEDS_FIX = False
+
+# use QT platform plugins if not set otherwise on GNOME desktop
+# based on QGnomePlatform
+if not os.environ.get('QT_QPA_PLATFORMTHEME'):
+    if os.environ.get('XDG_SESSION_DESKTOP'):
+        if os.environ['XDG_SESSION_DESKTOP'].lower() == 'gnome':
+            os.environ['QT_QPA_PLATFORMTHEME'] = 'gnome'
 
 # queue.Queue() needs threading module which might be not such a good idea to be used
 # because QThread is already in use
@@ -125,13 +131,12 @@ class AppInfo(object):
         contains app information previously located in GUI.py
     """
     NAME = 'Nagstamon'
-    VERSION = '3.8.0'
+    VERSION = '3.16.2'
     WEBSITE = 'https://nagstamon.de'
-    COPYRIGHT = '©2008-2021 Henri Wahl et al.'
+    COPYRIGHT = '©2008-2024 Henri Wahl et al.'
     COMMENTS = 'Nagios status monitor for your desktop'
     # dict of servers to offer for downloads if an update is available
-    DOWNLOAD_SERVERS = {'nagstamon.de': 'https://github.com/HenriWahl/Nagstamon/releases',
-                        'nagstamon.ifw-dresden.de': 'https://nagstamon.ifw-dresden.de/download'}
+    DOWNLOAD_SERVERS = {'nagstamon.de': 'https://github.com/HenriWahl/Nagstamon/releases'}
     # version URL depends on version string
     if 'alpha' in VERSION.lower() or \
         'beta' in VERSION.lower() or \
@@ -287,6 +292,12 @@ class Config(object):
         self.fullscreen_display = 0
         self.systray_offset_use = False
         self.systray_offset = 10
+        self.hide_macos_dock_icon = False
+        # as default enable on Linux Desktops like Cinnamon and Gnome Flashback
+        if DESKTOP_NEEDS_FIX:
+            self.enable_position_fix = True
+        else:
+            self.enable_position_fix = False
         self.font = ''
         self.defaults_acknowledge_sticky = False
         self.defaults_acknowledge_send_notification = False
@@ -321,38 +332,20 @@ class Config(object):
         # would not find a config file
         self.unconfigured = True
 
-        # adding cli args variable
-        self.cli_args = {}
-
-        # Parse the command line
-        parser = argparse.ArgumentParser(description='Nagstamon for your CLI')
-
-        # separate NagstaCLI from
-        if len(sys.argv) > 2 or (len(sys.argv) > 1 and sys.argv[1] in ['--help', '-h']):
-            parser.add_argument('--servername', type=str, help="name of the (Nagios)server. Look in nagstamon config")
-            parser.add_argument('--hostname', type=str)
-            parser.add_argument('--comment', type=str, default="")
-            parser.add_argument('--service', type=str, default="",
-                                help="specify service, if needed. Mostly the whole host goes to downstate")
-            parser.add_argument('--fixed', type=str, choices=['y', 'n'], default="y",
-                                help="fixed=n means wait for service/host to go down, then start the downtime")
-            parser.add_argument('--start_time', type=str, help="start time for downtime")
-            parser.add_argument('--hours', type=int, help="amount of hours for downtime")
-            parser.add_argument('--minutes', type=int, help="amount of minutes for downtime")
-            parser.add_argument('--config', type=str, help="Path for configuration folder")
-            parser.add_argument('--output', type=str, choices=['y', 'n'], default="y",
-                                help="lists given parameter (for debugging)")
-        else:
-            parser.add_argument('config', nargs='?', help='Path for configuration folder')
-
-        self.cli_args, unknown = parser.parse_known_args()
-
-        # try to use a given config file - there must be one given
-        if len(sys.argv) < 3 and self.cli_args.config:
-            # allow to give a config file
-            self.configdir = self.cli_args.config
-
-        # otherwise if there exits a configdir in current working directory it should be used
+        # get CLI arguments
+        parser = ArgumentParser(prog='nagstamon')
+        # mitigate session restore problem https://github.com/HenriWahl/Nagstamon/issues/878
+        if len(sys.argv) == 2 or len(sys.argv) >= 6:
+            # only add configdir if it might be included at all
+            parser.add_argument('configdir', default=None)
+        # -session and -name are used by X11 session management and could be
+        # safely ignored because nagstamon keeps its own session info
+        parser.add_argument('-session', default=None, required=False)
+        parser.add_argument('-name', default=None, required=False)
+        arguments, unknown_arguments = parser.parse_known_args()
+        if 'configdir' in arguments:
+            self.configdir = arguments.configdir
+        # otherwise if there exists a configdir in current working directory it should be used
         elif os.path.exists(os.getcwd() + os.sep + 'nagstamon.config'):
             self.configdir = os.getcwd() + os.sep + 'nagstamon.config'
         else:
@@ -451,6 +444,9 @@ class Config(object):
         # time saving config
         try:
             for server in servers:
+                # server name needs to be a string at every cost
+                # see issue https://github.com/HenriWahl/Nagstamon/issues/1010
+                servers[server].name = str(servers[server].name)
                 # usernames for monitor server and proxy
                 servers[server].username = self.DeObfuscate(servers[server].username)
                 servers[server].proxy_username = self.DeObfuscate(servers[server].proxy_username)
@@ -520,12 +516,11 @@ class Config(object):
                         config.read(self.configdir + os.sep + settingsdir + os.sep + settingsfile)
 
                         # create object for every setting
-                        name = config.sections()[0].replace(setting + '_', '', 1)
-
+                        name = config.get(config.sections()[0], 'name')
                         settings[name] = globals()[configobj]()
 
                         # go through all items of the server
-                        for i in config.items(setting + '_' + name):
+                        for i in config.items(config.sections()[0]):
                             # create a key of every config item with its appropriate value
                             if i[1] in BOOLPOOL:
                                 value = BOOLPOOL[i[1]]
@@ -769,15 +764,15 @@ class Config(object):
         """
         if OS == OS_WINDOWS:
             defaultactions = {"RDP": Action(name="RDP", description="Connect via RDP.",
-                                            type="command", string="C:\windows\system32\mstsc.exe /v:$ADDRESS$"),
+                                            type="command", string="C:/windows/system32/mstsc.exe /v:$ADDRESS$"),
                               "VNC": Action(name="VNC", description="Connect via VNC.",
-                                            type="command", string="C:\Program Files\TightVNC\vncviewer.exe $ADDRESS$"),
+                                            type="command", string="C:/Program Files/TightVNC/vncviewer.exe $ADDRESS$"),
                               "Telnet": Action(name="Telnet", description="Connect via Telnet.",
-                                               type="command", string="C:\Windows\System32\Telnet.exe root@$ADDRESS$"),
+                                               type="command", string="C:/Windows/System32\telnet.exe root@$ADDRESS$"),
                               "SSH": Action(name="SSH", description="Connect via SSH.",
                                             type="command",
-                                            string="C:\Program Files\PuTTY\putty.exe -l root $ADDRESS$")}
-        elif OS == OS_DARWIN:
+                                            string="C:/Program Files/PuTTY/putty.exe -l root $ADDRESS$")}
+        elif OS == OS_MACOS:
             defaultactions = {"RDP": Action(name="RDP", description="Connect via RDP.",
                                             type="command", string="open rdp://$ADDRESS$"),
                               "VNC": Action(name="VNC", description="Connect via VNC.",
@@ -959,6 +954,17 @@ class Server(object):
         self.host_filter = 'state !=0'
         self.service_filter = 'state !=0 or host.state != 0'
 
+        # For more information about he Opsview options below, see this link:
+        # https://knowledge.opsview.com/reference/api-status-filtering-service-objects
+
+        # The Opsview hashtag filter will filter out any services NOT having the
+        # listed hashtags (previously known as keywords).
+        self.hashtag_filter = ''
+        # The Opsview can_change_only option allows a user to show only
+        # services for which the user has permissions to make changes OR set
+        # downtimes.
+        self.can_change_only = False
+
         # Sensu/Uchiwa/??? Datacenter/Site config
         self.monitor_site = 'Site 1'
 
@@ -973,9 +979,17 @@ class Server(object):
         self.alertmanager_filter = ''
         self.map_to_critical = 'critical,error'
         self.map_to_warning = 'warning,warn'
+        self.map_to_down = 'down'
         self.map_to_unknown = 'unknown'
         self.map_to_ok = 'ok'
 
+        # IcingaDBWebNotificationsServer
+        self.notification_filter = "user.name=*"
+        self.notification_lookback = "30 minutes"
+
+        # Thruk
+        self.disabled_backends = ""
+
 class Action(object):
     """
     class for custom actions, which whill be thrown into one config dictionary like the servers
@@ -1062,7 +1076,6 @@ except Exception as err:
         # if resources dir is not available in CWD, try the
         # libs dir (site-packages) for the current Python
         from distutils.sysconfig import get_python_lib
-
         paths_to_check.append(os.path.normcase(os.path.join(get_python_lib(), "Nagstamon", "resources")))
     except Exception:
         pass
@@ -1070,7 +1083,6 @@ except Exception as err:
     # if we're still out of luck, maybe this was a user scheme install
     try:
         import site
-
         site.getusersitepackages()  # make sure USER_SITE is set
         paths_to_check.append(os.path.normcase(os.path.join(site.USER_SITE, "Nagstamon", "resources")))
     except Exception:
@@ -1082,6 +1094,12 @@ except Exception as err:
     for path in paths_to_check:
         if os.path.exists(path):
             RESOURCES = path
+            print('resources 3: ' + RESOURCES, paths_to_check)
             break
     else:
         RESOURCES = str(Path(__file__).parent.absolute().joinpath('resources'))
+
+# try to fix missing resources path for Windows
+if OS == OS_WINDOWS:
+    if r'\_internal\Nagstamon\resources' in RESOURCES:
+        RESOURCES = RESOURCES.replace(r'\_internal\Nagstamon\resources', r'\_internal\resources')
